@@ -17,3 +17,13 @@ class CinderProperties(object):
     SIZE = 'size'
     VOLUME_TYPE = 'volume_type'
     ATTACHMENTS = 'attachments'
+    DISPLAY_NAME = 'display_name'
+    ID = 'id'
+    STATUS = 'status'
+    CREATED_AT = 'created_at'
+    VOLUME_ATTACHMENT = 'volume_attachment'
+    INSTANCE_UUID = 'instance_uuid'
+    SERVER_ID = 'server_id'
+    VOLUME_ID = 'volume_id'
+    UPDATE_AT = 'updated_at'
+    TENANT_ID = 'tenant_id'
