@@ -14,9 +14,9 @@
 
 from oslo_config import cfg
 from oslo_log import log
-import six.moves.urllib.parse as urlparse
 from stevedore import driver
 import tenacity
+from urllib import parse as urlparse
 
 from vitrage.utils.datetime import utcnow
 
@@ -46,11 +46,15 @@ def get_connection_from_config():
 
     @tenacity.retry(
         wait=tenacity.wait_fixed(CONF.database.retry_interval),
-        stop=tenacity.stop_after_attempt(retries if retries >= 0 else 5),
+        stop=tenacity.stop_after_attempt(retries),
+        after=tenacity.after_log(LOG, log.WARN),
         reraise=True)
     def _get_connection():
         """Return an open connection to the database."""
-        return mgr.driver(url)
+        conn = mgr.driver(url)
+        session = conn._engine_facade.get_session()
+        session.execute('SELECT 1;')
+        return conn
 
     return _get_connection()
 
